This function get the verbosity level of the STarlight package which controls the amount of information that is printed to the console by the print_this_msg function.

get_verb_level()

Value

A vector

Examples

get_verb_level()
#> [1] 1