This function sets the verbosity level for the STarlight package, which controls the amount of information that is printed to the console by the print_this_msg function. The verbosity level can be set to any non-negative integer, with higher values indicating more detailed output. By default, the verbosity level is set to 1.

set_verb_level(verbosity_value)

Arguments

verbosity_value

A non-negative integer indicating the verbosity level to be set.

Examples

# Set verbosity level to 2
set_verb_level(2)

# Set verbosity level to 0
set_verb_level(0)