This class represents the result of a spatial transcriptomic comparison between two STGrid objects. It stores information such as conditions, methods, raw counts, scaling factors, and statistical test results.
conditionsA character vector specifying the conditions being compared.
methodA character vector specifying the technology used for each condition.
raw_countsA data.frame storing raw count data for each condition.
norm_countsA data.frame storing normalized counts for each condition.
scaling_factorA numeric vector representing the scaling factors used during normalization (to be divided).
stat_testA data frame containing statistical test results, including log2 ratios, odds ratios, and p-values for each feature.
pseudo_countThe value for the pseudo_count.
neighborhooda list of feature-feature neighborhood for the two conditions to be compared (not functional at the moment).
neighborhood_changesA feature-feature matrix indicative of neighborhood changes (not functional at the moment).
# Example usage:
example_dataset("11284296/files/cmp_xen")
#> |-- INFO : Dataset 11284296/files/cmp_xen has been loaded.
cmp_xen
#> Loading required package: stcompr
#> Warning: there is no package called ‘stcompr’
#> Error in .requirePackage(package): unable to find required package ‘stcompr’