R/utils.R
get_verb_level.Rd
This function get the verbosity level of the STarlight package which controls the amount of information that is printed to the console by the print_this_msg function.
print_this_msg
get_verb_level()
A vector
get_verb_level() #> [1] 1