This function calculates the sum of counts for each row in a spatial matrix.
sum_of_counts(spatial_matrix = NULL, control = NULL)The spatial matrix containing molecule counts, typically obtained from a spatial transcriptomics experiment.
A regular expression pattern indicating the controls in the dataset. Controls are internal features used for for monitoring experiments.
A numeric vector containing the sum of counts for each row in the spatial matrix.